@@ -1,10 +1,11 @@
 from d2ssect.utils import *
-from d2ssect import jellyfish
+import d2ssect.jellyfish as jellyfish
 import argparse, sys
 from operator import mul
 from functools import reduce
 from typing import Tuple
 import math, logging
+from os.path import basename,splitext
 
 import multiprocessing, subprocess
 from itertools import combinations
@@ -25,6 +26,7 @@ def main():
     parser.add_argument('-l','--jf_files', nargs='+', help='<Required> List of files from jellyfish count', required = True)
     parser.add_argument('-f','--seq_files',nargs='+', help='<Required> List of seq files(fasta/fastq), one for each sample, must aligned with jf files', required=True)
     parser.add_argument('-t','--threads',type=int, default=1,help='Number of threads to use, when sample size are big (>100), using more threads is suggested')
+    parser.add_argument('-p','--precision',type=int, default=6,help='Number of significant figures for numerical output')
     parser.add_argument('-o','--output',nargs='?',type=argparse.FileType('w'),default=sys.stdout)
     parser.add_argument('--debug',default=False, action='store_true',help="output intermedia results")
     args = parser.parse_args()
@@ -54,6 +56,8 @@ def main():
     logging.info(f'Number of pairwise d2s calculation: {len(index_combinations)}')
     d2s_combinations_list = []
 
+    sample_names = [splitext(basename(seqfile))[0] for seqfile in args.seq_files]
+
     if args.threads == 1:
         seqinfo_list = [ get_seqinfo(seqfile) for seqfile in args.seq_files ]
 
@@ -89,8 +93,13 @@ def main():
         d2s_matrix[i][j] = v
         d2s_matrix[j][i] = v
 
-    for row in d2s_matrix:
-        args.output.write('\t'.join(f'{score:.8f}' for score in row) + '\n')
+    for r in range(n_sample):
+        row = d2s_matrix[r]
+        sample = sample_names[r]
+        args.output.write(sample + '\t' + '\t'.join(f'{score:.{args.precision}f}' for score in row) + '\n')
+
+    # for row in d2s_matrix:
+    #     args.output.write('\t'.join(f'{score:.8f}' for score in row) + '\n')
 
 if __name__ == "__main__":
     main()
